class TextColor:
    default='\033[39m'
    black='\033[30m'
    red='\033[31m'
    green='\033[32m'
    yellow='\033[33m'
    blue='\033[34m'
    purple='\033[35m'
    cyan='\033[36m'
    lightgrey='\033[37m'
    darkgrey='\033[90m'
    lightred='\033[91m'
    lightgreen='\033[92m'
    lightyellow='\033[93m'
    lightblue='\033[94m'
    lightmagenta='\033[95m'
    lightcyan='\033[96m'
    white='\033[97m'

class BgColor:
    default="\033[49m"
    black="\033[40m"
    red="\033[41m"
    green="\033[42m"
    yellow="\033[43m"
    blue="\033[44m"
    purple="\033[45m"
    cyan="\033[46m"
    lightgrey="\033[47m"
    darkgrey="\033[100m"
    lightred="\033[101m"
    lightgreen="\033[102m"
    lightyellow="\033[103m"
    lightblue="\033[104m"
    lightmagenta="\033[105m"
    lightcyan="\033[106m"
    white="\033[107m"